bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.set_plotter
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.set_plotter